"use strict";

require("core-js/modules/es.symbol");

require("core-js/modules/es.array.filter");

require("core-js/modules/es.array.for-each");

require("core-js/modules/es.array.map");

require("core-js/modules/es.array.reduce");

require("core-js/modules/es.object.define-properties");

require("core-js/modules/es.object.define-property");

require("core-js/modules/es.object.get-own-property-descriptor");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/es.object.keys");

require("core-js/modules/es.regexp.exec");

require("core-js/modules/es.string.replace");

require("core-js/modules/es.string.sup");

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getChordTextScale = exports.transformChords = void 0;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var transformChords = function transformChords(bar) {
  var chords = bar.chords.map(function (chord) {
    return !chord.pitch ? chord : _objectSpread(_objectSpread({}, chord), {}, {
      pitch: replaceFlat(chord.pitch),
      chordType: getSpecialSymbol(chord.chordType),
      sup: chord.sup ? replaceFlat(chord.sup.substr(1, chord.sup.length - 2)) : null,
      bass: chord.bass ? replaceFlat(chord.bass.substr(1, chord.bass.length)) : null
    });
  });
  return _objectSpread(_objectSpread({}, bar), {}, {
    chords: chords
  });
};

exports.transformChords = transformChords;

var replaceFlat = function replaceFlat(str) {
  return str.replace(/b/g, "\u266D");
};

var getSpecialSymbol = function getSpecialSymbol(chordType) {
  if (chordType === "maj7") return "\u2206"; //  ∆

  if (chordType === "halfdim") return "\xF8"; //  ø

  return chordType.replace("dim", "\u2218"); // ∘
};

var getChordTextScale = function getChordTextScale(bars, barWidth) {
  /*
  F maj7
  Db maj7
  B halfdim
  F# halfdim
  F 7(sus4,9)
  Eb 7(sus4,9)
  Db major-13th
  Ab 7(#11,9,13)
  Eb 7(sus4,9,13)
  C suspended-fourth
  */
  var standardCharWidth = 17;
  var smallestCharWidth = bars.reduce(function (prev, bar, i) {
    var width = barWidth / bar.chords.length;
    var maxChorStringLength = getLengthFromLongestChordString(bar);
    var charWidth = maxChorStringLength ? width / maxChorStringLength : 0;
    return !prev ? charWidth : prev > charWidth ? charWidth : prev;
  }, null);
  if (standardCharWidth < smallestCharWidth) return 1;
  return smallestCharWidth / standardCharWidth;
};

exports.getChordTextScale = getChordTextScale;

var getLengthFromLongestChordString = function getLengthFromLongestChordString(bar) {
  return bar.chords.reduce(function (prev, chord, j) {
    var chordStringLength = ["pitch", "chordType", "sup"].reduce(function (prev, key) {
      return prev + (chord[key] ? chord[key].length : 0);
    }, 0);
    return !prev || chordStringLength > prev ? chordStringLength : prev;
  }, null);
};